@@ -4,6 +4,7 @@ from .package_data import PACKAGE_VERSION
 
 __version__ = PACKAGE_VERSION
 
-from .hackmudChatAPI import ChatAPI, token_refresh
+from .hackmudChatAPI import ChatAPI
+from .types import ChatMessage, TokenError
 
-__all__ = ["ChatAPI", "token_refresh"]
+__all__ = ["ChatAPI", "ChatMessage", "TokenError"]
